@@ -1,5 +1,7 @@
-import requests
+from time import sleep
 
+import requests
+from elasticsearch_dsl import UpdateByQuery
 
 
 class ElasticsearchFunctions:
@@ -8,7 +10,8 @@ class ElasticsearchFunctions:
         self.config = config
         self.session = requests.Session()
 
-    def check_or_create_index(self, esc, index_name, settings):
+    @staticmethod
+    def check_or_create_index(esc, index_name, settings):
         response = esc.indices.exists(index_name)
         if response is True:
             return "EXISTED"
@@ -18,40 +21,40 @@ class ElasticsearchFunctions:
 
     def create_index_pattern(self, dest_es_url, index_patter_name, namespace, date_field):
         headers = {'Accept': '*/*', 'kbn-xsrf': 'true', 'Content-Type': 'application/json'}
-        data = '{"attributes":{"title":"' + index_patter_name + '","timeFieldName":"' + date_field + '"}}'
+        data = f'{{"attributes":{{"title":"{index_patter_name}","timeFieldName":"{date_field}"}}}}'
         self.session.auth = (self.config.ES_USER, self.config.ES_PASSWORD)
-        if namespace:
-            post_url = dest_es_url + "/s/" + namespace + "/api/saved_objects/index-pattern"
-        else:
-            post_url = dest_es_url + "/api/saved_objects/index-pattern"
+
+        post_url = f"{dest_es_url}{f'/s/{namespace}' if namespace else ''}/api/saved_objects/index-pattern"
 
         response = self.session.post(post_url, headers=headers, data=data)
-        if response.status_code != 200:
-            print("error creating index {0} on {1}".format(index_patter_name, dest_es_url))
-            return
+
+        if response.status_code == 200:
+            return True
+        else:
+            print(f"error creating index {index_patter_name} on {dest_es_url}")
+            return False
 
     def create_space(self, url, namespace):
         headers = {'kbn-xsrf': 'true', 'Content-Type': 'application/json'}
-        data = '{"id": "' + namespace + '", "name": "' + namespace + '", "initials": "' + namespace.upper()[0:2] + '", "disabledFeatures":[]}'
+        data = f'{{"id": "{namespace}", "name": "{namespace}", "initials": "{namespace.upper()[0:2]}", ' \
+               f'"disabledFeatures":[]}}'
         self.session.auth = (self.config.ES_USER, self.config.ES_PASSWORD)
-        response = self.session.post(url + '/api/spaces/space', headers=headers, data=data)
+        response = self.session.post(f'{url}/api/spaces/space', headers=headers, data=data)
         return response == 200
 
-    def get_object_id(self, kib_url, namespace, type, name):
-        if namespace:
-            url = kib_url + "/s/" + namespace + "/api/saved_objects/_find"
-        else:
-            url = kib_url + "/api/saved_objects/_find"
+    def get_object_id(self, kib_url, namespace, type_str, name):
+
+        url = f"{kib_url}{f'/s/{namespace}' if namespace else ''}/api/saved_objects/_find"
 
         params = (
-            ('type', type),
+            ('type', type_str),
             ('search_fields', 'title'),
             ('search', name),
         )
         self.session.auth = (self.config.ES_USER, self.config.ES_PASSWORD)
         response = self.session.get(url, params=params, verify=False)
         if response.status_code != 200:
-            print("{0}, {1}, {2}, {3}".format(response.status_code, self.config.ES_USER, self.config.ES_PASSWORD, url))
+            print(f"{response.status_code}, {self.config.ES_USER}, {self.config.ES_PASSWORD}, {url}")
             return None
 
         response_json = response.json()
@@ -60,27 +63,27 @@ class ElasticsearchFunctions:
         else:
             return None
 
-    def get_index_pattern(self, url, namespace, id):
+    def get_index_pattern(self, url, namespace, id_str):
         headers = {
             'Accept': '*/*',
             'Content-Type': 'application/json'
         }
-        data = '[{"id":"' + str(id) + '","type":"index-pattern"}]'
+        data = f'[{{"id":"{str(id_str)}","type":"index-pattern"}}]'
         self.session.auth = (self.config.ES_USER, self.config.ES_PASSWORD)
-        if namespace:
-            bulk_url = '{0}/s/{1}/api/saved_objects/_bulk_get'.format(url, namespace)
-        else:
-            bulk_url = '{0}/api/saved_objects/_bulk_get'.format(url)
+
+        bulk_url = f"{url}{f'/s/{namespace}' if namespace else ''}/api/saved_objects/_bulk_get"
 
         response = self.session.post(bulk_url, headers=headers, data=data)
         return response.json()
 
-    def check_index_not_empty(self, index, esc):
+    @staticmethod
+    def check_index_not_empty(index, esc):
         empty_query = {}
         resav = esc.search(index=index, body=empty_query)
         return len(resav['hits']['hits']) > 0
 
-    def delete_from_day(self, esc, index, from_date, to_date):
+    @staticmethod
+    def delete_from_day(esc, index, from_date, to_date):
 
         query = '''{
                       "query": {
@@ -91,9 +94,27 @@ class ElasticsearchFunctions:
                                 }
                             }
                         }
-                    }'''% (from_date, to_date)
+                    }''' % (from_date, to_date)
         result = esc.delete_by_query(index, query)
         return result
 
-    def delete_index(self, esc, index):
+    @staticmethod
+    def delete_index(esc, index):
         esc.indices.delete(index=index, ignore=[400, 404])
+
+    @staticmethod
+    def run_update_by_query(esc, query, index):
+
+        ubq = UpdateByQuery(using=esc, index=index).update_from_dict(
+            query).params(request_timeout=100)
+        finished = False
+        count = 0
+        while not finished and count < 3:
+            try:
+                count += 1
+                ubq.execute()
+                finished = True
+            except Exception as e:
+                print(e)
+                sleep(10 * count)
+                pass
\ No newline at end of file
